@@ -25,11 +25,8 @@
 #define BOOT_IMAGE_H
 
 #include <gnome.h>
-
-
 #include "gst.h"
 
-
 #define MAX_IMAGES 16
 
 typedef enum {
@@ -38,7 +35,8 @@ typedef enum {
 	TYPE_WIN9X,
 	TYPE_DOS,
 	TYPE_LINUX,
-        TYPE_LINSWAP
+        TYPE_LINSWAP,
+	TYPE_HURD
 } GstBootImageType;
 
 typedef struct {
@@ -57,6 +55,8 @@ typedef struct {
 	gchar *root;
 	gchar *append;
 	gchar *initrd;
+	gchar *module;
+	gchar *password;
 } BootImage;
 
 BootImage        *boot_image_new          (void);
@@ -68,6 +68,7 @@ gchar            *boot_image_valid_label  (BootImage *image);
 gchar            *boot_image_valid_device (BootImage *image);
 gchar            *boot_image_valid_root   (BootImage *image);
 gchar            *boot_image_valid_initrd (BootImage *image);
+gchar            *boot_image_valid_module (BootImage *image);
 gchar            *boot_image_check        (BootImage *image);
 
 /* Helpers */
