@@ -45,7 +45,7 @@ enable_iface (GstIface *iface)
 				       gst_iface_get_dev (iface),
 				       NULL);
       gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						_("Check that the settings are apropriate for "
+						_("Check that the settings are correct for "
 						  "this network and that the computer is correctly "
 						  "connected to it."),
 						NULL);
@@ -236,7 +236,7 @@ on_detect_modem_clicked (GtkWidget *widget, gpointer data)
 				  NULL);
       gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (d),
 						_("Check that the device is not busy and "
-						  "that is correctly attached to the computer"),
+						  "that is correctly attached to the computer."),
 						NULL);
       gtk_dialog_run (GTK_DIALOG (d));
       gtk_widget_destroy (d);
@@ -516,3 +516,10 @@ on_gateway_combo_changed (GtkWidget *widget, gpointer data)
       g_free (gateway);
     }
 }
+
+gboolean
+on_connection_dialog_close (GtkWidget *widget, GdkEvent *event, gpointer data)
+{
+  gtk_widget_hide (widget);
+  return TRUE;
+}
