@@ -183,7 +183,7 @@ on_delete_share_clicked (GtkWidget *widget, gpointer data)
 						 GTK_BUTTONS_NONE,
 						 _("Are you sure you want to delete this share?"));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  _("Other computers in your network will stop viewing this"));
+							  _("Other computers in your network will stop viewing this."));
 		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT,
@@ -327,3 +327,12 @@ on_share_smb_settings_clicked (GtkWidget *widget, gpointer data)
 	if (response == GTK_RESPONSE_OK)
 		smb_settings_save ();
 }
+
+void
+on_dialog_validate (GtkWidget *widget, gpointer data)
+{
+	GtkWidget *ok_button;
+
+	ok_button = gst_dialog_get_widget (tool->main_dialog, "share_properties_ok");
+	gtk_widget_set_sensitive (ok_button, share_settings_validate ());
+}
