@@ -458,11 +458,11 @@ ntp_use_toggled (GtkWidget *w, GstDialog *dialog)
 						  GTK_DIALOG_MODAL,
 						  GTK_MESSAGE_INFO,
 						  GTK_BUTTONS_CLOSE,
-						  _("NTP support is not running"));
+						  _("NTP support is not installed"));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
-							  _("Please run NTP support in the system to enable "
+							  _("Please install and activate NTP support in the system to enable "
 							    "synchronization of your local time server with "
-							    "internet time servers"));
+							    "internet time servers."));
 		gtk_dialog_run (GTK_DIALOG (message));
 		gtk_widget_destroy (message);
 		return;
